void __stdcall BindMoniker(int p0, int p1, int p2, int p3) {}
void __stdcall CLIPFORMAT_UserFree(int p0, int p1) {}
void __stdcall CLIPFORMAT_UserFree64(int p0, int p1) {}
void __stdcall CLIPFORMAT_UserMarshal(int p0, int p1, int p2) {}
void __stdcall CLIPFORMAT_UserMarshal64(int p0, int p1, int p2) {}
void __stdcall CLIPFORMAT_UserSize(int p0, int p1, int p2) {}
void __stdcall CLIPFORMAT_UserSize64(int p0, int p1, int p2) {}
void __stdcall CLIPFORMAT_UserUnmarshal(int p0, int p1, int p2) {}
void __stdcall CLIPFORMAT_UserUnmarshal64(int p0, int p1, int p2) {}
void __stdcall CLSIDFromProgID(int p0, int p1) {}
void __stdcall CLSIDFromProgIDEx(int p0, int p1) {}
void __stdcall CLSIDFromString(int p0, int p1) {}
void __stdcall CoAddRefServerProcess() {}
void __stdcall CoAllowSetForegroundWindow(int p0, int p1) {}
void __stdcall CoAllowUnmarshalerCLSID(int p0) {}
void __stdcall CoBuildVersion() {}
void __stdcall CoCancelCall(int p0, int p1) {}
void __stdcall CoCopyProxy(int p0, int p1) {}
void __stdcall CoCreateFreeThreadedMarshaler(int p0, int p1) {}
void __stdcall CoCreateGuid(int p0) {}
void __stdcall CoCreateInstance(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CoCreateInstanceEx(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall CoCreateInstanceFromApp(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall CoDecodeProxy(int p0, int p1, int p2, int p3) {}
void __stdcall CoDecrementMTAUsage(int p0) {}
void __stdcall CoDisableCallCancellation(int p0) {}
void __stdcall CoDisconnectContext(int p0) {}
void __stdcall CoDisconnectObject(int p0, int p1) {}
void __stdcall CoDosDateTimeToFileTime(int p0, int p1, int p2) {}
void __stdcall CoEnableCallCancellation(int p0) {}
void __stdcall CoFileTimeNow(int p0) {}
void __stdcall CoFileTimeToDosDateTime(int p0, int p1, int p2) {}
void __stdcall CoFreeAllLibraries() {}
void __stdcall CoFreeLibrary(int p0) {}
void __stdcall CoFreeUnusedLibraries() {}
void __stdcall CoFreeUnusedLibrariesEx(int p0, int p1) {}
void __stdcall CoGetApartmentType(int p0, int p1) {}
void __stdcall CoGetCallContext(int p0, int p1) {}
void __stdcall CoGetCallerTID(int p0) {}
void __stdcall CoGetCancelObject(int p0, int p1, int p2) {}
void __stdcall CoGetClassObject(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CoGetContextToken(int p0) {}
void __stdcall CoGetCurrentLogicalThreadId(int p0) {}
void __stdcall CoGetCurrentProcess() {}
void __stdcall CoGetDefaultContext(int p0, int p1, int p2) {}
void __stdcall CoGetInstanceFromFile(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall CoGetInstanceFromIStorage(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall CoGetInterceptor(int p0, int p1, int p2, int p3) {}
void __stdcall CoGetInterceptorFromTypeInfo(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CoGetInterfaceAndReleaseStream(int p0, int p1, int p2) {}
void __stdcall CoGetMalloc(int p0, int p1) {}
void __stdcall CoGetMarshalSizeMax(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall CoGetObject(int p0, int p1, int p2, int p3) {}
void __stdcall CoGetObjectContext(int p0, int p1) {}
void __stdcall CoGetPSClsid(int p0, int p1) {}
void __stdcall CoGetStandardMarshal(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall CoGetStdMarshalEx(int p0, int p1, int p2) {}
void __stdcall CoGetSystemSecurityPermissions(int p0, int p1) {}
void __stdcall CoGetTreatAsClass(int p0, int p1) {}
void __stdcall CoImpersonateClient() {}
void __stdcall CoIncrementMTAUsage(int p0) {}
void __stdcall CoInitialize(int p0) {}
void __stdcall CoInitializeEx(int p0, int p1) {}
void __stdcall CoInitializeSecurity(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8) {}
void __stdcall CoInstall(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CoInvalidateRemoteMachineBindings(int p0) {}
void __stdcall CoIsHandlerConnected(int p0) {}
void __stdcall CoIsOle1Class(int p0) {}
void __stdcall CoLoadLibrary(int p0, int p1) {}
void __stdcall CoLockObjectExternal(int p0, int p1, int p2) {}
void __stdcall CoMarshalHresult(int p0, int p1) {}
void __stdcall CoMarshalInterThreadInterfaceInStream(int p0, int p1, int p2) {}
void __stdcall CoMarshalInterface(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall CoQueryAuthenticationServices(int p0, int p1) {}
void __stdcall CoQueryClientBlanket(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall CoQueryProxyBlanket(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall CoRegisterActivationFilter(int p0) {}
void __stdcall CoRegisterChannelHook(int p0, int p1) {}
void __stdcall CoRegisterClassObject(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CoRegisterDeviceCatalog(int p0, int p1) {}
void __stdcall CoRegisterInitializeSpy(int p0, int p1) {}
void __stdcall CoRegisterMallocSpy(int p0) {}
void __stdcall CoRegisterMessageFilter(int p0, int p1) {}
void __stdcall CoRegisterPSClsid(int p0, int p1) {}
void __stdcall CoRegisterSurrogate(int p0) {}
void __stdcall CoReleaseMarshalData(int p0) {}
void __stdcall CoReleaseServerProcess() {}
void __stdcall CoResumeClassObjects() {}
void __stdcall CoRevertToSelf() {}
void __stdcall CoRevokeClassObject(int p0) {}
void __stdcall CoRevokeDeviceCatalog(int p0) {}
void __stdcall CoRevokeInitializeSpy(int p0, int p1) {}
void __stdcall CoRevokeMallocSpy() {}
void __stdcall CoSetCancelObject(int p0) {}
void __stdcall CoSetProxyBlanket(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall CoSuspendClassObjects() {}
void __stdcall CoSwitchCallContext(int p0, int p1) {}
void __stdcall CoTaskMemAlloc(int p0) {}
void __stdcall CoTaskMemFree(int p0) {}
void __stdcall CoTaskMemRealloc(int p0, int p1) {}
void __stdcall CoTestCancel() {}
void __stdcall CoTreatAsClass(int p0, int p1) {}
void __stdcall CoUninitialize() {}
void __stdcall CoUnmarshalHresult(int p0, int p1) {}
void __stdcall CoUnmarshalInterface(int p0, int p1, int p2) {}
void __stdcall CoWaitForMultipleHandles(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CoWaitForMultipleObjects(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CreateAntiMoniker(int p0) {}
void __stdcall CreateBindCtx(int p0, int p1) {}
void __stdcall CreateClassMoniker(int p0, int p1) {}
void __stdcall CreateDataAdviseHolder(int p0) {}
void __stdcall CreateDataCache(int p0, int p1, int p2, int p3) {}
void __stdcall CreateFileMoniker(int p0, int p1) {}
void __stdcall CreateGenericComposite(int p0, int p1, int p2) {}
void __stdcall CreateILockBytesOnHGlobal(int p0, int p1, int p2) {}
void __stdcall CreateItemMoniker(int p0, int p1, int p2) {}
void __stdcall CreateObjrefMoniker(int p0, int p1) {}
void __stdcall CreateOleAdviseHolder(int p0) {}
void __stdcall CreatePointerMoniker(int p0, int p1) {}
void __stdcall CreateStdProgressIndicator(int p0, int p1, int p2, int p3) {}
void __stdcall CreateStreamOnHGlobal(int p0, int p1, int p2) {}
void __stdcall DcomChannelSetHResult(int p0, int p1, int p2) {}
void __stdcall DoDragDrop(int p0, int p1, int p2, int p3) {}
void __stdcall FmtIdToPropStgName(int p0, int p1) {}
void __stdcall FreePropVariantArray(int p0, int p1) {}
void __stdcall GetClassFile(int p0, int p1) {}
void __stdcall GetConvertStg(int p0) {}
void __stdcall GetHGlobalFromILockBytes(int p0, int p1) {}
void __stdcall GetHGlobalFromStream(int p0, int p1) {}
void __stdcall GetRunningObjectTable(int p0, int p1) {}
void __stdcall HACCEL_UserFree(int p0, int p1) {}
void __stdcall HACCEL_UserFree64(int p0, int p1) {}
void __stdcall HACCEL_UserMarshal(int p0, int p1, int p2) {}
void __stdcall HACCEL_UserMarshal64(int p0, int p1, int p2) {}
void __stdcall HACCEL_UserSize(int p0, int p1, int p2) {}
void __stdcall HACCEL_UserSize64(int p0, int p1, int p2) {}
void __stdcall HACCEL_UserUnmarshal(int p0, int p1, int p2) {}
void __stdcall HACCEL_UserUnmarshal64(int p0, int p1, int p2) {}
void __stdcall HBITMAP_UserFree(int p0, int p1) {}
void __stdcall HBITMAP_UserFree64(int p0, int p1) {}
void __stdcall HBITMAP_UserMarshal(int p0, int p1, int p2) {}
void __stdcall HBITMAP_UserMarshal64(int p0, int p1, int p2) {}
void __stdcall HBITMAP_UserSize(int p0, int p1, int p2) {}
void __stdcall HBITMAP_UserSize64(int p0, int p1, int p2) {}
void __stdcall HBITMAP_UserUnmarshal(int p0, int p1, int p2) {}
void __stdcall HBITMAP_UserUnmarshal64(int p0, int p1, int p2) {}
void __stdcall HDC_UserFree(int p0, int p1) {}
void __stdcall HDC_UserFree64(int p0, int p1) {}
void __stdcall HDC_UserMarshal(int p0, int p1, int p2) {}
void __stdcall HDC_UserMarshal64(int p0, int p1, int p2) {}
void __stdcall HDC_UserSize(int p0, int p1, int p2) {}
void __stdcall HDC_UserSize64(int p0, int p1, int p2) {}
void __stdcall HDC_UserUnmarshal(int p0, int p1, int p2) {}
void __stdcall HDC_UserUnmarshal64(int p0, int p1, int p2) {}
void __stdcall HGLOBAL_UserFree(int p0, int p1) {}
void __stdcall HGLOBAL_UserFree64(int p0, int p1) {}
void __stdcall HGLOBAL_UserMarshal(int p0, int p1, int p2) {}
void __stdcall HGLOBAL_UserMarshal64(int p0, int p1, int p2) {}
void __stdcall HGLOBAL_UserSize(int p0, int p1, int p2) {}
void __stdcall HGLOBAL_UserSize64(int p0, int p1, int p2) {}
void __stdcall HGLOBAL_UserUnmarshal(int p0, int p1, int p2) {}
void __stdcall HGLOBAL_UserUnmarshal64(int p0, int p1, int p2) {}
void __stdcall HICON_UserFree(int p0, int p1) {}
void __stdcall HICON_UserFree64(int p0, int p1) {}
void __stdcall HICON_UserMarshal(int p0, int p1, int p2) {}
void __stdcall HICON_UserMarshal64(int p0, int p1, int p2) {}
void __stdcall HICON_UserSize(int p0, int p1, int p2) {}
void __stdcall HICON_UserSize64(int p0, int p1, int p2) {}
void __stdcall HICON_UserUnmarshal(int p0, int p1, int p2) {}
void __stdcall HICON_UserUnmarshal64(int p0, int p1, int p2) {}
void __stdcall HMENU_UserFree(int p0, int p1) {}
void __stdcall HMENU_UserFree64(int p0, int p1) {}
void __stdcall HMENU_UserMarshal(int p0, int p1, int p2) {}
void __stdcall HMENU_UserMarshal64(int p0, int p1, int p2) {}
void __stdcall HMENU_UserSize(int p0, int p1, int p2) {}
void __stdcall HMENU_UserSize64(int p0, int p1, int p2) {}
void __stdcall HMENU_UserUnmarshal(int p0, int p1, int p2) {}
void __stdcall HMENU_UserUnmarshal64(int p0, int p1, int p2) {}
void __stdcall HMONITOR_UserFree(int p0, int p1) {}
void __stdcall HMONITOR_UserFree64(int p0, int p1) {}
void __stdcall HMONITOR_UserMarshal(int p0, int p1, int p2) {}
void __stdcall HMONITOR_UserMarshal64(int p0, int p1, int p2) {}
void __stdcall HMONITOR_UserSize(int p0, int p1, int p2) {}
void __stdcall HMONITOR_UserSize64(int p0, int p1, int p2) {}
void __stdcall HMONITOR_UserUnmarshal(int p0, int p1, int p2) {}
void __stdcall HMONITOR_UserUnmarshal64(int p0, int p1, int p2) {}
void __stdcall HPALETTE_UserFree(int p0, int p1) {}
void __stdcall HPALETTE_UserFree64(int p0, int p1) {}
void __stdcall HPALETTE_UserMarshal(int p0, int p1, int p2) {}
void __stdcall HPALETTE_UserMarshal64(int p0, int p1, int p2) {}
void __stdcall HPALETTE_UserSize(int p0, int p1, int p2) {}
void __stdcall HPALETTE_UserSize64(int p0, int p1, int p2) {}
void __stdcall HPALETTE_UserUnmarshal(int p0, int p1, int p2) {}
void __stdcall HPALETTE_UserUnmarshal64(int p0, int p1, int p2) {}
void __stdcall HRGN_UserFree(int p0, int p1) {}
void __stdcall HRGN_UserMarshal(int p0, int p1, int p2) {}
void __stdcall HRGN_UserSize(int p0, int p1, int p2) {}
void __stdcall HRGN_UserUnmarshal(int p0, int p1, int p2) {}
void __stdcall HWND_UserFree(int p0, int p1) {}
void __stdcall HWND_UserFree64(int p0, int p1) {}
void __stdcall HWND_UserMarshal(int p0, int p1, int p2) {}
void __stdcall HWND_UserMarshal64(int p0, int p1, int p2) {}
void __stdcall HWND_UserSize(int p0, int p1, int p2) {}
void __stdcall HWND_UserSize64(int p0, int p1, int p2) {}
void __stdcall HWND_UserUnmarshal(int p0, int p1, int p2) {}
void __stdcall HWND_UserUnmarshal64(int p0, int p1, int p2) {}
void __stdcall IIDFromString(int p0, int p1) {}
void __stdcall IsAccelerator(int p0, int p1, int p2, int p3) {}
void __stdcall MkParseDisplayName(int p0, int p1, int p2, int p3) {}
void __stdcall MonikerCommonPrefixWith(int p0, int p1, int p2) {}
void __stdcall MonikerRelativePathTo(int p0, int p1, int p2, int p3) {}
void __stdcall OleBuildVersion() {}
void __stdcall OleConvertIStorageToOLESTREAM(int p0, int p1) {}
void __stdcall OleConvertIStorageToOLESTREAMEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall OleConvertOLESTREAMToIStorage(int p0, int p1, int p2) {}
void __stdcall OleConvertOLESTREAMToIStorage2(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall OleConvertOLESTREAMToIStorageEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall OleConvertOLESTREAMToIStorageEx2(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9) {}
void __stdcall OleCreate(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall OleCreateDefaultHandler(int p0, int p1, int p2, int p3) {}
void __stdcall OleCreateEmbeddingHelper(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall OleCreateEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9, int p10, int p11) {}
void __stdcall OleCreateFromData(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall OleCreateFromDataEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9, int p10, int p11) {}
void __stdcall OleCreateFromFile(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall OleCreateFromFileEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9, int p10, int p11, int p12) {}
void __stdcall OleCreateLink(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall OleCreateLinkEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9, int p10, int p11) {}
void __stdcall OleCreateLinkFromData(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall OleCreateLinkFromDataEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9, int p10, int p11) {}
void __stdcall OleCreateLinkToFile(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall OleCreateLinkToFileEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9, int p10, int p11) {}
void __stdcall OleCreateMenuDescriptor(int p0, int p1) {}
void __stdcall OleCreateStaticFromData(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall OleDestroyMenuDescriptor(int p0) {}
void __stdcall OleDoAutoConvert(int p0, int p1) {}
void __stdcall OleDraw(int p0, int p1, int p2, int p3) {}
void __stdcall OleDuplicateData(int p0, int p1, int p2) {}
void __stdcall OleFlushClipboard() {}
void __stdcall OleGetAutoConvert(int p0, int p1) {}
void __stdcall OleGetClipboard(int p0) {}
void __stdcall OleGetClipboardWithEnterpriseInfo(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall OleGetIconOfClass(int p0, int p1, int p2) {}
void __stdcall OleGetIconOfFile(int p0, int p1) {}
void __stdcall OleInitialize(int p0) {}
void __stdcall OleIsCurrentClipboard(int p0) {}
void __stdcall OleIsRunning(int p0) {}
void __stdcall OleLoad(int p0, int p1, int p2, int p3) {}
void __stdcall OleLoadFromStream(int p0, int p1, int p2) {}
void __stdcall OleLockRunning(int p0, int p1, int p2) {}
void __stdcall OleMetafilePictFromIconAndLabel(int p0, int p1, int p2, int p3) {}
void __stdcall OleNoteObjectVisible(int p0, int p1) {}
void __stdcall OleQueryCreateFromData(int p0) {}
void __stdcall OleQueryLinkFromData(int p0) {}
void __stdcall OleRegEnumFormatEtc(int p0, int p1, int p2) {}
void __stdcall OleRegEnumVerbs(int p0, int p1) {}
void __stdcall OleRegGetMiscStatus(int p0, int p1, int p2) {}
void __stdcall OleRegGetUserType(int p0, int p1, int p2) {}
void __stdcall OleRun(int p0) {}
void __stdcall OleSave(int p0, int p1, int p2) {}
void __stdcall OleSaveToStream(int p0, int p1) {}
void __stdcall OleSetAutoConvert(int p0, int p1) {}
void __stdcall OleSetClipboard(int p0) {}
void __stdcall OleSetContainedObject(int p0, int p1) {}
void __stdcall OleSetMenuDescriptor(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall OleTranslateAccelerator(int p0, int p1, int p2) {}
void __stdcall OleUninitialize() {}
void __stdcall ProgIDFromCLSID(int p0, int p1) {}
void __stdcall PropStgNameToFmtId(int p0, int p1) {}
void __stdcall PropVariantClear(int p0) {}
void __stdcall PropVariantCopy(int p0, int p1) {}
void __stdcall ReadClassStg(int p0, int p1) {}
void __stdcall ReadClassStm(int p0, int p1) {}
void __stdcall ReadFmtUserTypeStg(int p0, int p1, int p2) {}
void __stdcall RegisterDragDrop(int p0, int p1) {}
void __stdcall ReleaseStgMedium(int p0) {}
void __stdcall RevokeDragDrop(int p0) {}
void __stdcall RoGetAgileReference(int p0, int p1, int p2, int p3) {}
void __stdcall SNB_UserFree(int p0, int p1) {}
void __stdcall SNB_UserFree64(int p0, int p1) {}
void __stdcall SNB_UserMarshal(int p0, int p1, int p2) {}
void __stdcall SNB_UserMarshal64(int p0, int p1, int p2) {}
void __stdcall SNB_UserSize(int p0, int p1, int p2) {}
void __stdcall SNB_UserSize64(int p0, int p1, int p2) {}
void __stdcall SNB_UserUnmarshal(int p0, int p1, int p2) {}
void __stdcall SNB_UserUnmarshal64(int p0, int p1, int p2) {}
void __stdcall STGMEDIUM_UserFree(int p0, int p1) {}
void __stdcall STGMEDIUM_UserFree64(int p0, int p1) {}
void __stdcall STGMEDIUM_UserMarshal(int p0, int p1, int p2) {}
void __stdcall STGMEDIUM_UserMarshal64(int p0, int p1, int p2) {}
void __stdcall STGMEDIUM_UserSize(int p0, int p1, int p2) {}
void __stdcall STGMEDIUM_UserSize64(int p0, int p1, int p2) {}
void __stdcall STGMEDIUM_UserUnmarshal(int p0, int p1, int p2) {}
void __stdcall STGMEDIUM_UserUnmarshal64(int p0, int p1, int p2) {}
void __stdcall SetConvertStg(int p0, int p1) {}
void __stdcall StgConvertPropertyToVariant(int p0, int p1, int p2, int p3) {}
void __stdcall StgConvertVariantToProperty(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall StgCreateDocfile(int p0, int p1, int p2, int p3) {}
void __stdcall StgCreateDocfileOnILockBytes(int p0, int p1, int p2, int p3) {}
void __stdcall StgCreatePropSetStg(int p0, int p1, int p2) {}
void __stdcall StgCreatePropStg(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall StgCreateStorageEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall StgGetIFillLockBytesOnFile(int p0, int p1) {}
void __stdcall StgGetIFillLockBytesOnILockBytes(int p0, int p1) {}
void __stdcall StgIsStorageFile(int p0) {}
void __stdcall StgIsStorageILockBytes(int p0) {}
void __stdcall StgOpenAsyncDocfileOnIFillLockBytes(int p0, int p1, int p2, int p3) {}
void __stdcall StgOpenPropStg(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall StgOpenStorage(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall StgOpenStorageEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall StgOpenStorageOnILockBytes(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall StgPropertyLengthAsVariant(int p0, int p1, int p2, int p3) {}
void __stdcall StgSetTimes(int p0, int p1, int p2, int p3) {}
void __stdcall StringFromCLSID(int p0, int p1) {}
void __stdcall StringFromGUID2(int p0, int p1, int p2) {}
void __stdcall StringFromIID(int p0, int p1) {}
void __stdcall WriteClassStg(int p0, int p1) {}
void __stdcall WriteClassStm(int p0, int p1) {}
void __stdcall WriteFmtUserTypeStg(int p0, int p1, int p2) {}
